export default {
    "index": 20,
    "lineNumber": 3,
    "column": 1,
    "message": "Unexpected token }"
};